@@ -46,6 +46,7 @@ L<WebService::SOP::Auth::V1_1>
 
 =head1 LICENSE
 
+Copyright (C) dataSpring, Inc.
 Copyright (C) Research Panel Asia, Inc.
 
 This library is free software; you can redistribute it and/or modify
@@ -53,7 +54,7 @@ it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-yowcowvg E<lt>yoko_ohyama [ at ] voyagegroup.comE<gt>
+yowcow E<lt>yoko.oyama [ at ] d8aspring.comE<gt>
 
 =cut
 
